@@ -1,9 +1,12 @@
+""" entry points to pastescript
+"""
 import sys
 from .urldispatcher import URLDispatcher
 
 
-def make_urldispatch_application(global_conf, **settings):
-    patterns = [p.split("=", 1) 
+def make_urldispatch_application(_, **settings):
+    """ paste.app_factory interface for URLDispatcher"""
+    patterns = [p.split("=", 1)
                 for p in settings['patterns'].split('\n')
                 if p]
     application = URLDispatcher()
